#!/usr/bin/env python
"""set environment variable"""
import travis_env
import click

MODULE_NAME = "travis_env.set"
PROG_NAME = 'python -m %s' % MODULE_NAME
USAGE = 'python -m %s repo var_name var_value' % MODULE_NAME


@click.command()
@click.argument('repo', required=True)
@click.argument('var_name', required=True)
@click.argument('var_value', required=True)
def _cli(repo, var_name, var_value):
    kwargs = {}
    kwargs[var_name] = var_value
    travis_env.update(repo, **kwargs)


if __name__ == '__main__':
    _cli(prog_name=PROG_NAME)



#!/usr/bin/env python
"""clear all environment variables"""
import travis_env
import click

MODULE_NAME = "travis_env.clear"
PROG_NAME = 'python -m %s' % MODULE_NAME
USAGE = 'python -m %s repo' % MODULE_NAME


@click.command()
@click.argument('repo', required=True)
def _cli(repo):
    travis_env.clear(repo)


if __name__ == '__main__':
    _cli(prog_name=PROG_NAME)



#!/usr/bin/env python
import json
import os
import requests


def request(method, url, data=None, **kwargs):
    """make request and return response"""
    TRAVIS_TOKEN = os.getenv("TRAVIS_TOKEN")
    if "headers" not in kwargs:
        kwargs["headers"] = {}
    kwargs["headers"].update({
        "Authorization": "token %s" % TRAVIS_TOKEN,
        "Travis-API-Version": "3",
        "Content-Type": "application/json",
        "Accept": "application/json"
    })
    if data is not None:
        data = json.dumps(data)
    r = requests.request(method, url, data=data, **kwargs)
    r.raise_for_status()
    return r



__all__ = ['vars', 'add', 'clear', 'delete', 'patch', 'update']


import os
import travis_env.api

"""
https://docs.travis-ci.com/api/#settings-environment-variables
"""


def vars(repo):
    ENDPOINT = os.getenv("TRAVIS_ENDPOINT", "https://api.travis-ci.org")
    url = "%s/repo/%s/env_vars" % (ENDPOINT, repo.replace("/", "%2F"))
    r = travis_env.api.request("GET", url)
    return {var["name"]: var["id"] for var in r.json()["env_vars"]}


def add(repo, var_name, var_value, public=False):
    """add environment variable"""
    ENDPOINT = os.getenv("TRAVIS_ENDPOINT", "https://api.travis-ci.org")
    data = {
        "env_var.name": var_name,
        "env_var.value": var_value,
        "env_var.public": public
    }
    url = "%s/repo/%s/env_vars" % (ENDPOINT, repo.replace("/", "%2F"))
    r = travis_env.api.request("POST", url, data)
    return r.json()


def patch(repo, var_id, var_value, public=None):
    """patch environment variable value"""
    ENDPOINT = os.getenv("TRAVIS_ENDPOINT", "https://api.travis-ci.org")
    data = {
        "env_var.value": var_value
    }
    if public is not None:
        data.update(public=public)
    url = "%s/repo/%s/env_var/%s" % (ENDPOINT,
                                     repo.replace("/", "%2F"), var_id)
    r = travis_env.api.request("PATCH", url, data)
    return r.json()


def update(repo, **kwargs):
    """update environment variable"""
    data = vars(repo)
    for var_name, var_value in kwargs.items():
        if var_name not in data:
            add(repo, var_name, var_value)
        else:
            var_id = data[var_name]
            patch(repo, var_id, var_value)


def delete(repo, var_name):
    """delete environment variable"""
    ENDPOINT = os.getenv("TRAVIS_ENDPOINT", "https://api.travis-ci.org")
    var_id = vars(repo).get(var_name, None)
    if var_id:
        url = "%s/repo/%s/env_var/%s" % (ENDPOINT,
                                         repo.replace("/", "%2F"), var_id)
        travis_env.api.request("DELETE", url)


def clear(repo):
    """clear all environment variables"""
    ENDPOINT = os.getenv("TRAVIS_ENDPOINT", "https://api.travis-ci.org")
    for var_name, var_id in vars(repo).items():
        url = "%s/repo/%s/env_var/%s" % (ENDPOINT,
                                         repo.replace("/", "%2F"), var_id)
        travis_env.api.request("DELETE", url)



#!/usr/bin/env python
"""delete environment variables by name"""
import travis_env
import click

MODULE_NAME = "travis_env.delete"
PROG_NAME = 'python -m %s' % MODULE_NAME
USAGE = 'python -m %s repo var_name ...' % MODULE_NAME


@click.command()
@click.argument('repo', required=True)
@click.argument('name', nargs=-1, required=True)
def _cli(repo, var_names):
    for var_name in var_names:
        travis_env.delete(var_name)


if __name__ == '__main__':
    _cli(prog_name=PROG_NAME)
